@@ -178,7 +178,7 @@ def bib_entries(entries):
     Drop @string / @comment / @preamble entries.
     """
     for e in entries:
-        if e["type"] not in ["string", "comment", "preamble"]:
+        if e["type"].lower() not in ["string", "comment", "preamble"]:
             yield e
 
 
@@ -209,7 +209,11 @@ def highlight_text(text, highlight):
     """
     Return `text` with sub-string `highlight` in bold.
     """
-    text = re.sub(highlight, bold(highlight), text)
+
+    def highlighter(s):
+        return bold(s.group(0))
+
+    text = re.sub(highlight, highlighter, text, flags=re.IGNORECASE)
     # Drop ANSI unbold followed by ANSI bold
     return text.replace(_ANSI_UNBOLD + _ANSI_BOLD, "")
 
@@ -232,7 +236,7 @@ def highlight_match(
             )
         else:
             for val in vals:
-                if val in text:
+                if val.lower() in text.lower():
                     text = highlight_text(text, val)
                 else:
                     extra_match_val = extra_match_info.get(key, result.entry[key])
